/*
    ParaGUI - crossplatform widgetset
    Copyright (C) 2000,2001  Alexander Pipelka

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Alexander Pipelka
    pipelka@teleweb.at

    Last Update:      $Author: pipelka $
    Update Date:      $Date: 2001/04/24 16:51:08 $
    Source File:      $Source: /usr/local/CVSROOT/linux/paragui/include/Attic/paragui_doc.h,v $
    CVS/RCS Revision: $Revision: 1.1.2.1 $
    Status:           $State: Exp $
*/

/*! \mainpage ParaGUI Documentation

	\section intro Introduction
	ParaGUI is a cross-platform high-level application framework and GUI (graphical user interface) library.<br>
	It can be compiled on various platforms (Linux, Win32, BeOS, MacOS, ...)<br><br>
	ParaGUI is completely based on the Simple DirectMedia Layer (SDL).<br>
	ParaGUI is targeted on crossplatform multimedia applications and
	embedded devices operating on framebuffer displays.

	\section highlights Highlights of the library
	
	published under LGPL<br>
	straight forward C++ class-design (see the API documentation)<br>
	asynchronous messagehandling (messageposts between objects)<br>
	multithreaded<br>
	highly customizable widgets<br>
	(background gradients, background images, transparency, colors, fonts)<br>
	many standard widgets already implemented<br>
	(buttons, labels, scrollbars, progressbars, windows ...)<br>
	create your own widgets<br>
	(subclass an existing widget) <br>
	supports various imagetypes through SDL_Image (configurable at compile time)


	\section install Installation
	
	\subsection step1 Installing from RPM
	That's the easiest method:
			
	rpm -Uhv paragui-x.x.x.rpm<br>
	rpm -Uhv paragui-devel-x.x.x.rpm<br>
			
	and you're set.

	\subsection step2 Installing from a tarball
	A bit more work but also quite easy:
			
	tar -zxvf paragui-x.x.x.tar.gz<br>
	cd paragui-x.x.x<br><br>
	./configure<br>
	or: ./configure --enable-pgimage		(for SDL_Image support)<br><br>
	make<br>
	make install [as root]
			
*/

/**	\page coding Coding conventions for ParaGUI
<body>

<h2>The Easy Route</h2>

<p>
Grab astyle, a code formatter for C, C++, and Java, from
<a href="http://astyle.sourceforge.net">
http://astyle.sourceforge.net</a>.
All code in the repository should be run through astyle
before being committed, with these options:
</p>
<pre>astyle --style=kr --indent=tab <filename></pre>
<p>Or, to make life easy, you can put <a href="./astylerc">
this file</a> in ~/.astylerc and just run: </p>
<pre>astyle <filename></pre>

<p>Doing this has several advantages:</p>
<ul>
	<li>Code in the repository will be consistently
	    formatted.</li>
	<li>You don't have to worry about the coding
	    conventions while coding, or at all for that
	    matter.</li>
	<li>You can reformat code to your own personal
	    style preference while working on it, and
	    then easily convert it back to the way it was,
	    along with your added code.  Since astyle will
	    format it in the exact same way, patches won't
	    be filled with many lines of useless formatting
	    changes.</li>
	<li>It's easy ;).</li>
</ul>

<p>Note: don't make a habit of formatting all source files
("just to be sure") instead of just the ones you modified.
This will update the timestamps on the files and cause all
hell to break loose.</p>

<p>Here's an outline of the code format, for the sake of
completeness.. but use astyle. Please. :)</p>

<h2>Sample code:</h2>

<pre>
// No, this code is not supposed to make sense
void foo(int bar) {
	if (bar < 7) {
		cout << bar << endl;
	}
	else {
		cout << "That's a big bar you got there.\n"
	}
}
</pre>

<h2>Things to notice:</h2>

<ul>
	<li>C++ (//) style comments are best for few-line comments</li>
	<li>Use C comments for commenting large blocks</li>
	<li>K&R style braces, with one space before the first brace</li>
	<li>No spaces padding the inside of parenthesis</li>
	<li>One space padding of operators on both sides</li>
	<li>An if statement's block will always be enclosed in braces,
	    even if it is just one line.</li>
	<li>Hard tabs for indents</li>
	<li>And the most important thing of all, no matter what you do:
	  <b>Do not assume anything about the length of a tab.</b>
	  This means don't mix tabs and spaces in an interchangeable way.
	  This way, everything that looks nice in an editor with 8-space
	  tabs, will look just fine in an editor with 4-space tabs, etc.
	</li>
</ul>

</body>
*/

/**	\page requirements	Requirements for compiling ParaGUI

	ParaGUI is completely based on PG_ from Sam Lantinga. <br>
	You have to checkout the following libs from his <a href="http://www.libpg.org">website</a>: <p>

	<h2><b>ParaGUI Version <= 0.5.2: </b></h2><p>

	PG_ (Simple Directmedia Layer) Version <= 1.1.4 <br>
	SDL_ttf (True Type Font Rendering Engine for PG_) Version <= 1.2.1 <br>
	FreeType >= 1.2.0 <p>

	<h2><b>ParaGUI Version >= 0.5.3: </b></h2><p>

	PG_ (Simple Directmedia Layer) Version >= 1.1.5 <br>
	or the latest snapshot from the CVS repository <br>
	SDL_ttf (True Type Font Rendering Engine for PG_) Version >= 1.2.2 <br>
	FreeType >= 1.2.0<br>

	<h2><b>ParaGUI Version >= 0.6.5: </b></h2><p>

	PG_ (Simple Directmedia Layer) Version >= 1.2.0 <br>
	or the latest snapshot from the CVS repository <br>
	SDL_ttf (True Type Font Rendering Engine for PG_) Version >= 1.2.2 <br>
	FreeType >= 1.2.0<br>
	SDL_Image >= 1.1.0 (if enabled)<br>
*/

/**	\page	contribute	Contributing (A small CVS guide)

<br>
<ol>
<li>Download the sourcetree via CVS<br>
<br>
<i>cvs -d :pserver:guest@www.bms-austria.com:/usr/local/CVSROOT login<br>
password: guest<br>
<br>
cvs -d :pserver:guest@www.bms-austria.com:/usr/local/CVSROOT -z3 checkout -r rel-0-6-5 paragui<br>
<br>
sh autogen.sh<br>
./configure<br>
make<br>
make install (as root)<br>
<br><br>
</i>
<li>Make your changes<br>
<br>
<li>Sync with the repository<br>
<br>
<i>cvs -z3 update -d -P<br>
</i>
<br><br>
<li>Create a patchfile<br>
<br>
<i>cvs -z3 diff -c3p<br>
</i>
<br><br>
<li>Send the patchfile via email to <a href="mailto:pipelka@bms-austria.com">me</a><br>
Please give a short (or even longer) description what the patch exactly does.<br>
<br><br>
</ol>
*/

/**	\page	roadmap		The current roadmap (TODO's and plans)

\verbinclude TODO

*/

/**
	\page	tut1		TUTORIAL 1 - application initialization, eventloop
	\include tut1.cpp
*/

/**
	\page tut2		TUTORIAL 2 - our first widget (a button)
	\include tut2.cpp
*/

/**
	\page tut3		TUTORIAL 3 - callback functions
	\include tut3.cpp
*/

/**
	\page tut4		TUTORIAL 4 - custom widgets
	\include tut4.cpp
*/

/**
	\page tut5		TUTORIAL 5 - member callbacks, message exchange between widgets
	\include tut5.cpp
*/

/**
	\page tut6		TUTORIAL 6 - mouse event functions - part 1
	\include tut6.cpp
*/

/**
	\page tut7		TUTORIAL 7 - mouse event functions - part 2
	\include tut7.cpp
*/
